package com.blackberry.workspaces.sdk.api.examples;

import java.util.Date;
import java.util.HashSet;
import java.util.List;

import com.blackberry.workspaces.sdk.api.APISession;
import com.blackberry.workspaces.sdk.api.UploadManager;
import com.blackberry.workspaces.sdk.api.UploadResult;
import com.blackberry.workspaces.sdk.api.enums.DeviceType;
import com.blackberry.workspaces.sdk.api.enums.WhoCanView;
import com.blackberry.workspaces.sdk.api.json.PermissionFromUserJson;
import com.blackberry.workspaces.sdk.api.json.RoomRecipientsJson;
import com.blackberry.workspaces.sdk.api.json.SubmitDocumentSdsJson;
import com.blackberry.workspaces.sdk.api.json.SubmitDocumentsVdrJson;

/**
 * Examples of uploading a file
 * @author tasfaw
 *
 */
public class UploadFilesExample {
        private APISession apiSession;

        /**
         * Creates an instances of the UploadFilesExample class
         * 
         * @param apiSession An ApiSession instance to be used.
         */
        public UploadFilesExample(APISession apiSession)
        {
            this.apiSession = apiSession;
        }

        /**
         * UploadDocument
         * 
         * @param localPath
         * @param filename
         * @param userRecipients
         * @param ADGroupsRecipients
         * @param listRecipients
         * @return
         */
        public UploadResult uploadDocument(String localPath, String filename, HashSet<String> userRecipients, HashSet<String> ADGroupsRecipients, HashSet<String> listRecipients)
        {
            // START SNIPPET: devGuide17
            // Get an instance of UploadManager
            UploadManager uploadManager = apiSession.getUploadManager();

            // Create a new SubmitDocumentSdsJson JSON
            SubmitDocumentSdsJson uploadInfo = new SubmitDocumentSdsJson();
            HashSet<String> documentGuids = new HashSet<String>();
            documentGuids.add(uploadManager.getNewGuidForDocument());
                // Create a new permission JSON
            PermissionFromUserJson permissionJson = new PermissionFromUserJson();
            permissionJson.setCopy(true);
            permissionJson.setDownload(true);
            permissionJson.setDownloadOriginal(false);
            permissionJson.setExpirationDate(new Date());
            uploadInfo.setPermission(permissionJson);
            uploadInfo.setUserRecipients(userRecipients);
            uploadInfo.setActiveDirectoryGroupsRecipients(ADGroupsRecipients);
            uploadInfo.setWhoCanView( WhoCanView.RECEIPIENTS_ONLY);
            uploadInfo.setDocumentGuids(documentGuids);

            // A call to the UploadDocument
            UploadResult uploadResult =
                uploadManager.uploadDocument(uploadInfo, localPath, null, filename, null);

            // END SNIPPET: devGuide17
            return uploadResult;
        }

        /**
         * UploadDocumentToRoom
         * 
         * @param roomId
         * @param destinationFileName
         * @param filename
         * @param folder
         * @param groups
         * @param domains
         * @return
         */
        public UploadResult uploadDocumentToRoom(int roomId, String destinationFileName, String filename, String folder, List<String> groups, List<String> domains)
        {
            // START SNIPPET: devGuide16
            // Get an instance of UploadManager
            UploadManager uploadManager = apiSession.getUploadManager();

            // Create a new SubmitDocumentsVdrJson JSON
            SubmitDocumentsVdrJson uploadInfo = new SubmitDocumentsVdrJson();
            uploadInfo.setOpenForAllRoom(false);
            RoomRecipientsJson recipientsJson = new RoomRecipientsJson();
            recipientsJson.setGroups(groups);
            recipientsJson.setDomains(domains);
            uploadInfo.setRecipients(recipientsJson);
            uploadInfo.setFolder(folder);
            uploadInfo.setTagValueList(null);
            uploadInfo.setDeviceType(DeviceType.SYNC);

            // A call to the UploadDocumentToRoom
            UploadResult uploadResult = uploadManager.uploadDocumentToRoom(uploadInfo,
                roomId, destinationFileName, filename, null, false);

            // END SNIPPET: devGuide16
            return uploadResult;
        }
}
